@@ -6,6 +6,7 @@ EXTENSIONS = {
     'asciidoc': {'text', 'asciidoc'},
     'apinotes': {'text', 'apinotes'},
     'asar': {'binary', 'asar'},
+    'astro': {'text', 'astro'},
     'avif': {'binary', 'image', 'avif'},
     'avsc': {'text', 'avro-schema'},
     'bash': {'text', 'shell', 'bash'},
@@ -56,6 +57,7 @@ EXTENSIONS = {
     'ear': {'binary', 'zip', 'jar'},
     'edn': {'text', 'clojure', 'edn'},
     'ejs': {'text', 'ejs'},
+    'ejson': {'text', 'json', 'ejson'},
     'env': {'text', 'dotenv'},
     'eot': {'binary', 'eot'},
     'eps': {'binary', 'eps'},
